@@ -6,24 +6,25 @@ test_that("plotInObservation works", {
   # summariseInObservationPlot plot ----
   x <- summariseInObservation(cdm$observation_period, interval = "years")
   expect_no_error(inherits(plotInObservation(x), "ggplot"))
-  x <-  x |> dplyr::filter(result_id == -1)
+  x <- x |> dplyr::filter(result_id == -1)
   expect_error(plotInObservation(x))
 
-  expect_error(plotInObservation(summariseInObservation(cdm$observation_period, interval = "years", output = c("person-days", "records"), ageGroup = NULL, sex = FALSE)))
+  expect_error(plotInObservation(summariseInObservation(cdm$observation_period, interval = "years", output = c("person-days", "record"), ageGroup = NULL, sex = FALSE)))
 
   x <- summariseInObservation(cdm$observation_period, interval = "years", output = "person-days", ageGroup = NULL, sex = FALSE)
   expect_true(inherits(plotInObservation(x), "ggplot"))
 
-  x <- summariseInObservation(cdm$observation_period, interval = "years", output = "records", ageGroup = NULL, sex = FALSE)
+  x <- summariseInObservation(cdm$observation_period, interval = "years", output = "record", ageGroup = NULL, sex = FALSE)
   expect_true(inherits(plotInObservation(x), "ggplot"))
 
   result <- cdm$observation_period |>
     summariseInObservation(
-      output = c("person-days", "records"),
+      output = c("person-days", "record"),
       sex = TRUE,
       ageGroup = list(
         "0-19" = c(0, 19), "20-39" = c(20, 39), "40-59" = c(40, 59),
-        "60-79" = c(60, 79), "80 or above" = c(80, Inf))
+        "60-79" = c(60, 79), "80 or above" = c(80, Inf)
+      )
     )
 
   expect_error(plotInObservation(result))
